1D examples
-----------

.. raw:: html

  <div class="row d-flex justify-content-center">
      <div class="card col-md-5 m-2 text-center">
        <div class="card-body d-flex align-items-center">
          <video class="w-100" control autoplay loop="loop" alt="Suni">
            <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/1D/advection.mp4" type="video/mp4">
            Your browser does not support the video tag.
          </video>
        </div>
        <div class="card-footer">
          <a href="https://github.com/pylbm/pylbm_gallery/blob/master/1D/p_system.py">
            Advection
          </a>
        </div>
      </div>

      <div class="card col-md-5 m-2 text-center">
        <div class="card-body d-flex align-items-center">
        <video class="w-100" control autoplay loop="loop" alt="Suni">
          <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/1D/p-system.mp4" type="video/mp4">
          Your browser does not support the video tag.
        </video>
        </div>
        <div class="card-footer">
        <a href="https://github.com/pylbm/pylbm_gallery/blob/master/1D/p_system.py">
          p-system
        </a>
        </div>
      </div>

      <div class="card col-md-5 m-2 text-center">
        <div class="card-body d-flex align-items-center">
        <video class="w-100" control autoplay loop="loop" alt="Suni">
          <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/1D/burgers.mp4" type="video/mp4">
          Your browser does not support the video tag.
        </video>
        </div>
        <div class="card-footer">
          <a href="https://github.com/pylbm/pylbm_gallery/blob/master/1D/burgers.py">
            Burgers
          </a>
        </div>
      </div>

      <div class="card col-md-5 m-2 text-center">
        <div class="card-body d-flex align-items-center">
          <img class="w-100" src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/1D/euler.png"/>
        </div>
        <div class="card-footer">
          <a href="https://github.com/pylbm/pylbm_gallery/blob/master/1D/euler.py">
            Euler
          </a>
        </div>
      </div>
  </div>


2D examples
-----------

.. raw:: html

  <div class="row d-flex justify-content-center">
      <div class="card col-md-5 m-2 text-center">
        <div class="card-body d-flex align-items-center">
          <video class="w-100" control autoplay loop="loop" alt="Suni">
            <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/2D/Karman_vortex_street/Re%3D250/Karman_vortex_street.mp4" type="video/mp4">
            <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/2D/Karman_vortex_street/Re%3D250/Karman_vortex_street.ogv" type="video/ogg">
            Your browser does not support the video tag.
          </video>
        </div>
        <div class="card-footer">
          <a href="https://github.com/pylbm/pylbm_gallery/blob/master/2D/Karman_vortex_street/Re%3D250/Karman_vortex_street.py">
            Vortex street (Re = 250)
          </a>
        </div>
      </div>

      <div class="card col-md-5 m-2 text-center">
        <div class="card-body d-flex align-items-center">
          <video class="w-100" control autoplay loop="loop" alt="Suni">
            <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/2D/Karman_vortex_street/Re%3D2500/Karman_vortex_street.mp4" type="video/mp4">
            <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/2D/Karman_vortex_street/Re%3D2500/Karman_vortex_street.ogv" type="video/ogg">
            Your browser does not support the video tag.
          </video>
        </div>
        <div class="card-footer">
          <a href="https://github.com/pylbm/pylbm_gallery/blob/master/2D/Karman_vortex_street/Re%3D2500/Karman_vortex_street.py">
            Vortex street (Re = 2500)
          </a>
        </div>
      </div>

      <div class="card col-md-5 m-2 text-center">
        <div class="card-body d-flex align-items-center">
          <video class="w-100" control autoplay loop="loop" alt="Suni">
            <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/2D/Rayleigh_Benard/Rayleigh_Benard.mp4" type="video/mp4">
            <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/2D/Rayleigh_Benard/Rayleigh_Benard.ogv" type="video/ogg">
            Your browser does not support the video tag.
          </video>
        </div>
        <div class="card-footer">
          <a href="https://github.com/pylbm/pylbm_gallery/blob/master/2D/Rayleigh_Benard/Rayleigh-Benard.py">
            Rayleigh Benard
          </a>
        </div>
      </div>

      <div class="card col-md-5 m-2 text-center">
        <div class="card-body d-flex align-items-center">
          <video class="w-100" control autoplay loop="loop" alt="Suni">
            <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/2D/shallow_water/shallow_water.mp4" type="video/mp4">
            <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/2D/shallow_water/shallow_water.ogv" type="video/ogg">
            Your browser does not support the video tag.
          </video>
        </div>
        <div class="card-footer">
          <a href="https://github.com/pylbm/pylbm_gallery/blob/master/2D/shallow_water/shallow_water.py">
            Shallow water
          </a>
        </div>
      </div>

      <div class="card col-md-5 m-2 text-center">
        <div class="card-body d-flex align-items-center">
          <video class="w-100" control autoplay loop="loop" alt="Suni">
            <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/2D/Orszag_Tang/Orszag_Tang_vortex.avi" type="video/mp4">
            <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/2D/Orszag_Tang/Orszag_tang_vortex.ogv" type="video/ogg">
            Your browser does not support the video tag.
          </video>
        </div>
        <div class="card-footer">
          <a href="https://github.com/pylbm/pylbm_gallery/blob/master/2D/Orszag_Tang/Orszag_Tang_vortex.py">
            Orszag Tang Vortex
          </a>
        </div>
      </div>

      <div class="card col-md-5 m-2 text-center">
        <div class="card-body d-flex align-items-center">
          <video class="w-100" control autoplay loop="loop" alt="Suni">
            <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/2D/Air_cond/air_cond.avi" type="video/mp4">
            <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/2D/Air_cond/air_cond.ogv" type="video/ogg">
            Your browser does not support the video tag.
          </video>
        </div>
        <div class="card-footer">
          <a href="https://github.com/pylbm/pylbm_gallery/blob/master/2D/Air_cond/air_conditioning.py">
            Air Conditioning
          </a>
        </div>
      </div>
  </div>

3D examples
-----------

.. raw:: html

  <div class="row d-flex justify-content-center">
      <div class="card col-md-5 m-2 text-center">
        <div class="card-body d-flex align-items-center">
          <video class="w-100" control autoplay loop="loop" alt="Suni">
            <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/3D/advection/advection3d.mp4" type="video/mp4">
            <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/3D/advection/advection3d.ogv" type="video/ogg">
            Your browser does not support the video tag.
          </video>
        </div>
        <div class="card-footer">
          <a href="https://github.com/pylbm/pylbm_gallery/blob/master/3D/advection/advection.py">
            Advection
          </a>
        </div>
      </div>

      <div class="card col-md-5 m-2 text-center">
        <div class="card-body d-flex align-items-center">
          <iframe width="560" height="315" src="https://peertube.maly.io/videos/embed/b4253746-6241-41dc-affd-7f3287d92718" frameborder="0" allowfullscreen></iframe>
        </div>
        <div class="card-footer">
          <a href="https://github.com/pylbm/pylbm_gallery/blob/master/3D/karman/D3Q19_karman_sphere.py">
            Vortex street
          </a>
        </div>
      </div>

  </div>
